div_rem_burnikel_ziegler

Function div_rem_burnikel_ziegler 

fn div_rem_burnikel_ziegler(u: &BigUint, d: &BigUint) -> (BigUint, BigUint)
This algorithm is from Burnikel and Ziegler, “Fast Recursive Division”, Algorithm 1. It is a recursive algorithm that divides the dividend and divisor into blocks of digits and uses a divide-and-conquer approach to find the quotient.

The algorithm is more complex than the base algorithm, but it is faster for large operands.

Time complexity of this algorithm is the same as the algorithm used for the multiplication.

link: https://pure.mpg.de/rest/items/item_1819444_4/component/file_2599480/content